Regolith-Json-Template
======================

A Python package for easier reuseability of the JSON Template Regolith filter for Minecraft Bedrock Edition 

Documentation
-------------

This module is just a component used by the JSON Template Regolith filter and its intended to be used by that filter only. You can find the documentation of the filter on the page of the filter: https://github.com/Nusiq/regolith-filters/tree/master/json_template

Installation
-------------

.. code-block:: bash

   pip install regolith-json-template

